data

package
v0.0.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 12, 2024 License: MIT Imports: 14 Imported by: 1

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetContribution

func GetContribution(c context.Context, id string) (*vo.ContributionVO, error)

Get a single contribution.

  @Summary Get a contribution
	 @Description Retrieve a contribution from the data store.
	 @Param c
	 @Param id

func GetContributions

func GetContributions(c context.Context, params apiutil.QueryParams) ([]*vo.ContributionVO, error)

Get many contributions.

@Summary Query the datastore for contributions.
@Description Given a set of parameters, query the datastore for contributions that match.
@Param c A Context object
@Param params A QueryParams object that contains the parameters for the query

func GetLicense

func GetLicense(c context.Context, id string) (*vo.LicenseVO, error)

func GetLicenses

func GetLicenses(c context.Context, params apiutil.QueryParams) ([]*vo.LicenseVO, error)

func GetPerson

func GetPerson(c context.Context, id string) (*vo.PersonVO, error)

func GetPersons

func GetPersons(c context.Context, params apiutil.QueryParams) ([]*vo.PersonVO, error)

func GetPublisher

func GetPublisher(c context.Context, id string) (*vo.PublisherVO, error)

func GetPublishers

func GetPublishers(c context.Context, params apiutil.QueryParams) ([]*vo.PublisherVO, error)

func GetReview

func GetReview(c context.Context, id string) (*vo.ReviewVO, error)

func GetReviews

func GetReviews(c context.Context, params apiutil.QueryParams) ([]*vo.ReviewVO, error)

func GetStudio

func GetStudio(c context.Context, id string) (*vo.StudioVO, error)

func GetStudios

func GetStudios(c context.Context, params apiutil.QueryParams) ([]*vo.StudioVO, error)

func GetSystem

func GetSystem(c context.Context, id string) (*vo.SystemVO, error)

func GetSystems

func GetSystems(c context.Context, params apiutil.QueryParams) ([]*vo.SystemVO, error)

func GetVolume

func GetVolume(c context.Context, id string) (*vo.VolumeVO, error)

func GetVolumes

func GetVolumes(c context.Context, params apiutil.QueryParams) ([]*vo.VolumeVO, error)

Types

This section is empty.

Jump to